@@ -1,10 +1,10 @@
 package Alien::uv;
 use 5.012;
 
-our $VERSION = "1.28.0.3";
+our $VERSION = "1.28.0.4";
 
 use XS::Loader;
 
-XS::Loader::bootstrap();
+XS::Loader::load_noboot();
 
 1;
